Module: GeminiOmniAi
- Defined in:
- lib/gemini_omni_ai.rb
Constant Summary collapse
- VERSION =
"0.1.0"- WEBSITE =
"https://gemini-omni.online"- SUPPORT =
"support@gemini-omni.online"
Class Method Summary collapse
Class Method Details
.info ⇒ Object
6 7 8 9 10 11 12 13 14 |
# File 'lib/gemini_omni_ai.rb', line 6 def self.info { name: "Gemini Omni", title: "Gemini Omni AI Video Generator | Omni Video Online", website: WEBSITE, support: SUPPORT, description: "Gemini Omni turns text prompts and images into polished omni video clips. Generate ads, social reels, and launch content with Gemini Omni AI." } end |